@@ -77,10 +77,6 @@ class JinjaConverter:
 
         type, type_rules = self.get_type(field_name, field_data)
 
-        rules = self.get_validation_list(field_name, field_data)
-        if type_rules:
-            rules += type_rules
-
         # Since "null" and "false" are valid defaults we can't rely on default being defined.
         # To get around that we have `has_default`.
 
@@ -91,6 +87,10 @@ class JinjaConverter:
             has_default = True
             default = self.get_default(type, field_data.get("default"))
 
+        rules = self.get_validation_list(field_name, field_data, allow_none=not required)
+        if type_rules:
+            rules += type_rules
+
         return {
             "name": field_name,
             "type": type,
@@ -109,7 +109,7 @@ class JinjaConverter:
         if "enum" in field_data:
             if "type" not in field_data:
                 field_data["type"] = "string"
-            type_validators.append(validators.oneof(field_name, field_data["enum"]))
+            type_validators.append(validators.oneof(field_name, field_data["enum"], allow_none=False))
 
         if "type" not in field_data:
             print(field_data)
@@ -165,12 +165,12 @@ class JinjaConverter:
 
         return "null"
 
-    def get_validation_list(self, field_name, field_data):
+    def get_validation_list(self, field_name, field_data, allow_none):
         tf_rules = []
         for key, value in field_data.items():
             if not hasattr(validators, key.lower()):
                 continue
-            rule = getattr(validators, key.lower())(field_name, value)
+            rule = getattr(validators, key.lower())(field_name, value, allow_none)
             if rule:
                 tf_rules.append(rule)
 
