@@ -51,6 +51,10 @@ class MarkdownConverter(JinjaConverter):
                 continue
             fields.append(self.convert_field(schema, field_name, field_data))
 
+        # We need at least one field to make a table.
+        if len(fields) < 1:
+            return ""
+
         # Sort required fields to the top, then sort by alphabet.
         fields.sort(key=lambda t: (0 if t["Required"] == "Yes" else 1, t["Name"]))
 
